@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_FOLLOWUPREMINDER_H_
-#define MESSAGECOMPOSER_FOLLOWUPREMINDER_H_
+#pragma once
 
 #include "messagecomposer_export.h"
 
@@ -18,5 +17,3 @@ namespace FollowUpReminder
 Q_REQUIRED_RESULT MESSAGECOMPOSER_EXPORT bool isAvailableAndEnabled();
 }
 }
-
-#endif
